Disqus Comment Box
------------------

A comment box allowing users to add comments and start discussions can be added. A comment box can be added at the page level, but also for an individual section or question, allowing discussion of that particular content.

.. disqus::
    :shortname: interactivepython
    :identifier: discussion1

.. reveal:: disqus_src
   :showtitle: Show Source
   :hidetitle: Hide Source
   :modaltitle: Source for the example above

   .. code-block:: rst

      .. disqus::
          :shortname: interactivepython
          :identifier: discussion1

